==> FHLBBS-4.8.tgz: wbbs/post.c <==
#include "cgic.h"
#include "wbbs.c"
/*** ΨӪŪLY@g峹 ***/
void
brc_addlist(fname)
  char *fname;
{
  int ftime, n, i;

  if (!cuser.userlevel)
    return;

  ftime = atoi(&fname[2]);
  if (ftime <= 0)
  {
    return;
  }
  if (brc_num <= 0)
  {
    brc_list[brc_num++] = ftime;
    brc_changed = 1;
    return;
  }
  if ((brc_num == 1) && (ftime < brc_list[0]))
    return;
  for (n = 0; n < brc_num; n++)
  {
    if (ftime == brc_list[n])
    {
      return;
    }
    else if (ftime > brc_list[n])
    {
      if (brc_num < BRC_MAXNUM)
        brc_num++;
      for (i = brc_num - 1; --i >= n; brc_list[i + 1] = brc_list[i]);
      brc_list[n] = ftime;
      brc_changed = 1;
      return;
    }
  }
  if (brc_num < BRC_MAXNUM)
  {
    brc_list[brc_num++] = ftime;
    brc_changed = 1;
  }
}
int cgiMain() {
   FILE *fptr1,*fptr2;
   char name1[20],location1[100],title1[70],comment1[MAXLEN+1],date1[10],buf1[100];
   char *foo,filename1[70],filename2[50],filepath[100], *p,oneline[301];
   char receiver[20],name2[IDLEN+1];
   time_t t1;
   int len1, len2, fd, numposts, i=0, count;
   int postmode; // 0:`  1:w
   int target; //0:Qװ 1:Mail
   struct fileheader postfile, replyfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   char *bdname;
   char myfoo[18];
   char postname[NAMELEN+1];
   time_t ltime;
   char remotehost[256];
   int currmode;
   int uid;
   int sign,signyn;
   int where; /** Kn̥h =0 mlist =1 board.cgi**/
   int localsave; /*** ݬݬO_nK ****/
   /**** Bzɶ ****/
   t1 = time(0);
   strcpy(buf1,ctime(&t1));
   if(foo = rindex(buf1, '\n')) *foo = '\0';
   strncpy(date1,buf1+4,6);
   date1[6]='\0';
   
   /**** BzD ***/
   cgiFormString("title1", title1, 70);
   if (title1[0]==0) strcpy(title1,"LD....");
   cgiFormString("board1", currboard, IDLEN+1);
   /***** BzHp ***/
   cgiFormInteger("LOCALSAVE",&localsave,0);
   /********** BzñW ******/
   cgiFormInteger("SIGNYN",&signyn,0);
   cgiFormIntegerBounded("SIGNFILE",&sign,1,9,1);
   /**** Mw̫̥h ***/
   cgiFormInteger("WHERE", &where, 0);
   /**** MwOO H ***/
  /*****
   if (strcmp(currboard,"mail")) target=0;
   else target=1;
  */
   cgiFormInteger("TARGET", &target, 0);
   if (strrchr(currboard,'/')) //ȬOhacker
    {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
    }

   /*** @̾ ***/
   strncpy(remotehost,cgiRemoteHost,255);
   if (remotehost[0]==0)
      strncpy(remotehost,cgiRemoteAddr,255);
   remotehost[255]=0;
   //cgiFormInteger("numarticle", &numarticle, 0);
   comment1[MAXLEN-2]=0;
   cgiFormString("comment1", comment1, MAXLEN);//峹e
   cgiFormString("submit1", buf1, 30);
   if (strstr(buf1,"w")!=NULL) postmode=1;
   else postmode=0;
	
   if(!check_passwd())
      return(0);
 
   /*** ˬd峹 ***/
   if (comment1[MAXLEN-2])
   {
     cgiHeaderContentType("text/html");
     fprintf(cgiOut,"峹ӪAЧR᭫KI<p>\n");
     return(0);
   }
   strcpy(name1,cuser.userid); /*** nOiYɪuserid **/
   strcpy(name2,cuser.userid); /*** gJ峹}Yuser id **/
   if (target==0)
   {
      bdname=currboard;
      bp = getbcache(bdname);
      if((!bp)||(!Ben_Perm(bp))){
         cgiHeaderContentType("text/html");
         fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
         return(0);
      }
      /*******  ΦW ********/
      if (strcmp(bdname,"Anonymity")==0) 
      { 
 	    strcpy(name1,"");
        strcpy(name2,"anonymous");
        strcpy(postname,"@ADڬO");
	    strcpy(remotehost,"Wa");
        signyn=0;
      }
	else if (strcmp(bdname,"comfortable")==0)
      {
        strcpy(name2,"anonymous");
        strcpy(postname,"@ADڬO");
	    strcpy(remotehost,"Wa");
        signyn=0;
      }
      else
        strcpy(postname,cuser.username);
      if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM(bp->BM)))
      {
	     currmode |= (MODE_BOARD | MODE_POST);
      } 
      else if (haspostperm(bdname)) currmode |= MODE_POST;

      if (!((currmode)&(MODE_POST)))
      {
          cgiHeaderContentType("text/html");
         fprintf(cgiOut,"藍_AzثeLkbo峹I<p>\n");
         return(0); 
      }
   } 
   if (postmode)
   {
     cgiHeaderContentType("text/html");
     fprintf(cgiOut, "<HTML><HEAD>\n");
	fprintf(cgiOut, "<TITLE>wzҽs誺G</TITLE>\n");
	fprintf(cgiOut, "<font size=5 color=\"#ff0000\"><center>zoepU</center></font>\n");
	fprintf(cgiOut,"<hr>\n");
	fprintf(cgiOut,"<table>\n");
   }
   if (!postmode)
    {
      sprintf(filename2,"M.%d.A",t1);
      
      if (target) /** H ***/
	  {
	    cgiFormString("RECEIVER", receiver, 12);
	    sprintf(filename1,BBSHOME "/home/%s/%s",receiver,filename2);
	    fptr2 = fopen(filename1,"w");
	    fprintf(fptr2,"@: %s(%s)\n",name1,cuser.username);
	  }
      else /** Qװ **/
	  {
	    setbfile(filename1,bdname,filename2);
	    fptr2 = fopen(filename1,"w");
          fprintf(fptr2,"@: %s(%s) ݪO: %s\n",name2,postname,currboard);
	  }
      fprintf(fptr2,"D: %s\n",title1);
      fprintf(fptr2,"ɶ: %s\n",ctime(&t1));
	  fprintf(fptr2,"%s",comment1);
      /**** ñW ***/
      if (signyn)
      {
        sprintf(buf1, BBSHOME "/home/%s/sig.%d", cuser.userid,sign);
        fptr1 = fopen(buf1,"r");
        if (fptr1)
        { 
	  fprintf(fptr2,"\n--\n");
          while (fgets(oneline, 300, fptr1)) fprintf(fptr2,"%s",oneline);
          fclose(fptr1);
        }
      } 
      /*** 峹  **/
      fprintf(fptr2, END_TITLE
       " From: %s\n",  remotehost);
      fclose(fptr2);
    } 
    else /** w **/
    {
      if (target)
	    fprintf(cgiOut,"@: %s(%s)<br>\n",name1,cuser.username);
      else
        fprintf(cgiOut,"@: %s(%s) ݪO: %s<br>\n",name2,postname,currboard);
      fprintf(cgiOut,"D: %s<br>\n",title1);
      fprintf(cgiOut,"ɶ: %s<br>\n",ctime(&t1));
	  fprintf(cgiOut,"<pre>%s",comment1);
      if (signyn)
      {
        sprintf(buf1, BBSHOME "/home/%s/sig.%d", cuser.userid,sign);
        fptr1 = fopen(buf1,"r");
        if (fptr1)
        { 
	  fprintf(cgiOut,"\n--\n");
          while (fgets(oneline, 300, fptr1)) fprintf(cgiOut,"%s",oneline);
          fclose(fptr1);
        }
      } 
      fprintf(cgiOut, END_TITLE
       " From: %s\n</pre>",  remotehost); 
      fprintf(cgiOut,"</table>\n<hr>\n");
      fprintf(cgiOut,"<form method=\"POST\" action=\"post.cgi\"\n>");
    fprintf(cgiOut,"<input type=\"submit\" name=\"submit1\" value=\"iK\">");
    if (target) 
    {
      cgiFormString("RECEIVER", receiver, 12);
      fprintf(cgiOut,"<input type=\"hidden\" name=\"RECEIVER\" "
                        "value=\"%s\">\n",receiver);
    }
    else
    {
      fprintf(cgiOut,"<input type=\"hidden\" name=\"LOCALSAVE\" "
      "value=\"%d\">\n",localsave);
    }
    fprintf(cgiOut,"<input type=\"hidden\" name=\"WHERE\" "
      "value=\"%d\">\n",where);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"title1\" "
      "value=\"%s\">\n",title1);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"TARGET\" "
      "value=\"%d\">\n",target);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"SIGNYN\" "
      "value=\"%d\">\n",signyn);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"SIGNFILE\" "
      "value=\"%d\">\n",sign);
	fprintf(cgiOut,"<input type=\"hidden\" name=\"board1\" "
      "value=\"%s\">\n",currboard);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"comment1\" "
      "value=\"%s\">\n</form>", comment1);
     fprintf(cgiOut,"</body></html>\n");
      return 0;
    }

   strcpy(postfile.filename,filename2);
   strcpy(postfile.owner,name1);
   strcpy(postfile.title,title1);

   if (HAS_PERM(PERM_INTERNET)&&localsave) 
   	postfile.savemode='S'; //H
   else postfile.savemode='L'; //
   	//postfile.savemode=0x4d;
   	//postfile.savemode=0x4d;

   /*** gY ***/
   ltime=time(0);
   strftime(myfoo,18,"%D",localtime(&ltime));
   myfoo[5]=0;
   if (myfoo[0]=='0') myfoo[0]=' ';
   strcpy(postfile.date,myfoo);
   if (target)
   {
     sprintf(filepath,BBSHOME "/home/%s/",receiver);
     sprintf(buf1,"%s.DIR",filepath);
   }
   else
   {
     sprintf(filepath,BBSHOME "/boards/%s/",currboard);
     sprintf(buf1,"%s.DIR",filepath);
   }

   if (!postmode)
     {
     if((fd = open(buf1,O_RDWR | O_CREAT | O_APPEND,0666)) == -1){
        cgiHeaderContentType("text/html");
        fprintf(cgiOut,"buf1=%sYɶ}ɥ<P> \n", buf1);
        return -1;
     }

     if( stat(buf1, &st ) >= 0 )
        numposts = st.st_size / (sizeof( struct fileheader ));
     else
        numposts = 0;
     if(lseek(fd,sizeof(postfile)*numposts,SEEK_SET) == -1){
        close(fd);
        cgiHeaderContentType("text/html");
        fprintf(cgiOut,"ɮ׳Bz2<P>\n");
        return -1;
     }
     write(fd, &postfile, sizeof(postfile));
     close(fd);
   
  }
  /*********  iK\ *****/
   if ((target==0)&&(postmode==0)) //`postQװ
   {
      /**** OwgŪLF **/
      brc_initial(currboard);
      brc_addlist(postfile.filename);   
      brc_update();
      cuser.numposts=cuser.numposts+1;
	oneline[0]=(char) sign;
	cuser.uflag = (cuser.uflag & ~SIG_FLAG) | (oneline[0] & SIG_FLAG);
      uid = searchuser(cuser.userid) ;
      if((substitute_record(fn_passwd, &cuser, sizeof(cuser), uid) == -1)||
        (uid==0))
      {
	    cgiHeaderContentType("text/html");
  	    fprintf(cgiOut," register numberpost  fail!!!\n");
      }
      setuserid(uid, cuser.userid);
      setbfile(location1,currboard,"wpostnum");
      logcnt(location1);
   }
   /**** Is **/
   if (where)
      sprintf(location1, "mlist.cgi");
   else
       sprintf(location1, "boards.cgi?%s", currboard);
   cgiHeaderLocation(location1);

   /** HXh **/
   if ((target==0)&&(HAS_PERM(PERM_INTERNET))&&localsave)
   {
     sprintf(buf1,"%s/innd/out.bntp",BBSHOME);
     if (fptr1 = fopen(buf1, "a")){
        fprintf(fptr1, "%s\t%s\t%s\t%s\t%s\n", currboard,
        filename2, name1,"FROM.FHLWBBS", title1);
        fclose(fptr1);
     }
   }
   return 0;
}

==> FHLBBS-4.9.tgz: wbbs/post.c <==
#include "cgic.h"
#include "wbbs.c"
/*** ΨӪŪLY@g峹 ***/
void
brc_addlist(fname)
  char *fname;
{
  int ftime, n, i;

  if (!cuser.userlevel)
    return;

  ftime = atoi(&fname[2]);
  if (ftime <= 0)
  {
    return;
  }
  if (brc_num <= 0)
  {
    brc_list[brc_num++] = ftime;
    brc_changed = 1;
    return;
  }
  if ((brc_num == 1) && (ftime < brc_list[0]))
    return;
  for (n = 0; n < brc_num; n++)
  {
    if (ftime == brc_list[n])
    {
      return;
    }
    else if (ftime > brc_list[n])
    {
      if (brc_num < BRC_MAXNUM)
        brc_num++;
      for (i = brc_num - 1; --i >= n; brc_list[i + 1] = brc_list[i]);
      brc_list[n] = ftime;
      brc_changed = 1;
      return;
    }
  }
  if (brc_num < BRC_MAXNUM)
  {
    brc_list[brc_num++] = ftime;
    brc_changed = 1;
  }
}
int cgiMain() {
   FILE *fptr1,*fptr2;
   char name1[20],location1[100],title1[70],comment1[MAXLEN+1],date1[10],buf1[100];
   char *foo,filename1[70],filename2[50],filepath[100], *p,oneline[301];
   char receiver[20],name2[IDLEN+1];
   time_t t1;
   int len1, len2, fd, numposts, i=0, count;
   int postmode; // 0:`  1:w
   int target; //0:Qװ 1:Mail
   struct fileheader postfile, replyfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   char *bdname;
   char myfoo[20];
   char postname[NAMELEN+1];
   time_t ltime;
   char remotehost[256];
   int currmode;
   int uid;
   int sign,signyn;
   int where; /** Kn̥h =0 mlist =1 board.cgi**/
   int localsave; /*** ݬݬO_nK ****/
   /**** Bzɶ ****/
   t1 = time(0);
   strcpy(buf1,ctime(&t1));
   if(foo = rindex(buf1, '\n')) *foo = '\0';
   strncpy(date1,buf1+4,6);
   date1[6]='\0';
   
   /**** BzD ***/
   cgiFormString("title1", title1, 70);
   if (title1[0]==0) strcpy(title1,"LD....");
   cgiFormString("board1", currboard, IDLEN+1);
   /***** BzHp ***/
   cgiFormInteger("LOCALSAVE",&localsave,0);
   /********** BzñW ******/
   cgiFormInteger("SIGNYN",&signyn,0);
   cgiFormIntegerBounded("SIGNFILE",&sign,1,9,1);
   /**** Mw̫̥h ***/
   cgiFormInteger("WHERE", &where, 0);
   /**** MwOO H ***/
  /*****
   if (strcmp(currboard,"mail")) target=0;
   else target=1;
  */
   cgiFormInteger("TARGET", &target, 0);
   if (strrchr(currboard,'/')) //ȬOhacker
    {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
    }

   /*** @̾ ***/
   strncpy(remotehost,cgiRemoteHost,255);
   if (remotehost[0]==0)
      strncpy(remotehost,cgiRemoteAddr,255);
   remotehost[255]=0;
   //cgiFormInteger("numarticle", &numarticle, 0);
   comment1[MAXLEN-2]=0;
   cgiFormString("comment1", comment1, MAXLEN);//峹e
   cgiFormString("submit1", buf1, 30);
   if (strstr(buf1,"w")!=NULL) postmode=1;
   else postmode=0;
	
   if(!check_passwd())
      return(0);
 
   /*** ˬd峹 ***/
   if (comment1[MAXLEN-2])
   {
     cgiHeaderContentType("text/html");
     fprintf(cgiOut,"峹ӪAЧR᭫KI<p>\n");
     return(0);
   }
   strcpy(name1,cuser.userid); /*** nOiYɪuserid **/
   strcpy(name2,cuser.userid); /*** gJ峹}Yuser id **/
   if (target==0)
   {
      bdname=currboard;
      bp = getbcache(bdname);
      if((!bp)||(!Ben_Perm(bp))){
         cgiHeaderContentType("text/html");
         fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
         return(0);
      }
      /*******  ΦW ********/
      if (strcmp(bdname,"Anonymity")==0) 
      { 
 	    strcpy(name1,"");
        strcpy(name2,"anonymous");
        strcpy(postname,"@ADڬO");
	    strcpy(remotehost,"Wa");
        signyn=0;
      }
	else if (strcmp(bdname,"comfortable")==0)
      {
        strcpy(name2,"anonymous");
        strcpy(postname,"@ADڬO");
	    strcpy(remotehost,"Wa");
        signyn=0;
      }
      else
        strcpy(postname,cuser.username);
      if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM(bp->BM)))
      {
	     currmode |= (MODE_BOARD | MODE_POST);
      } 
      else if (haspostperm(bdname)) currmode |= MODE_POST;

      if (!((currmode)&(MODE_POST)))
      {
          cgiHeaderContentType("text/html");
         fprintf(cgiOut,"藍_AzثeLkbo峹I<p>\n");
         return(0); 
      }
   } 
   if (postmode)
   {
     cgiHeaderContentType("text/html");
     fprintf(cgiOut, "<HTML><HEAD>\n");
	fprintf(cgiOut, "<TITLE>wzҽs誺G</TITLE>\n");
	fprintf(cgiOut, "<font size=5 color=\"#ff0000\"><center>zoepU</center></font>\n");
	fprintf(cgiOut,"<hr>\n");
	fprintf(cgiOut,"<table>\n");
   }
   if (!postmode)
    {
      sprintf(filename2,"M.%d.A",t1);
      
      if (target) /** H ***/
	  {
	    cgiFormString("RECEIVER", receiver, 12);
	    sprintf(filename1,BBSHOME "/home/%s/%s",receiver,filename2);
	    fptr2 = fopen(filename1,"w");
	    fprintf(fptr2,"@: %s(%s)\n",name1,cuser.username);
	  }
      else /** Qװ **/
	  {
	    setbfile(filename1,bdname,filename2);
	    fptr2 = fopen(filename1,"w");
          fprintf(fptr2,"@: %s(%s) ݪO: %s\n",name2,postname,currboard);
	  }
      fprintf(fptr2,"D: %s\n",title1);
      fprintf(fptr2,"ɶ: %s\n",ctime(&t1));
	  fprintf(fptr2,"%s",comment1);
      /**** ñW ***/
      if (signyn)
      {
        sprintf(buf1, BBSHOME "/home/%s/sig.%d", cuser.userid,sign);
        fptr1 = fopen(buf1,"r");
        if (fptr1)
        { 
	  fprintf(fptr2,"\n--\n");
          while (fgets(oneline, 300, fptr1)) fprintf(fptr2,"%s",oneline);
          fclose(fptr1);
        }
      } 
      /*** 峹  **/
      fprintf(fptr2, END_TITLE
       " From: %s\n",  remotehost);
      fclose(fptr2);
    } 
    else /** w **/
    {
      if (target)
	    fprintf(cgiOut,"@: %s(%s)<br>\n",name1,cuser.username);
      else
        fprintf(cgiOut,"@: %s(%s) ݪO: %s<br>\n",name2,postname,currboard);
      fprintf(cgiOut,"D: %s<br>\n",title1);
      fprintf(cgiOut,"ɶ: %s<br>\n",ctime(&t1));
	  fprintf(cgiOut,"<pre>%s",comment1);
      if (signyn)
      {
        sprintf(buf1, BBSHOME "/home/%s/sig.%d", cuser.userid,sign);
        fptr1 = fopen(buf1,"r");
        if (fptr1)
        { 
	  fprintf(cgiOut,"\n--\n");
          while (fgets(oneline, 300, fptr1)) fprintf(cgiOut,"%s",oneline);
          fclose(fptr1);
        }
      } 
      fprintf(cgiOut, END_TITLE
       " From: %s\n</pre>",  remotehost); 
      fprintf(cgiOut,"</table>\n<hr>\n");
      fprintf(cgiOut,"<form method=\"POST\" action=\"post.cgi\"\n>");
    fprintf(cgiOut,"<input type=\"submit\" name=\"submit1\" value=\"iK\">");
    if (target) 
    {
      cgiFormString("RECEIVER", receiver, 12);
      fprintf(cgiOut,"<input type=\"hidden\" name=\"RECEIVER\" "
                        "value=\"%s\">\n",receiver);
    }
    else
    {
      fprintf(cgiOut,"<input type=\"hidden\" name=\"LOCALSAVE\" "
      "value=\"%d\">\n",localsave);
    }
    fprintf(cgiOut,"<input type=\"hidden\" name=\"WHERE\" "
      "value=\"%d\">\n",where);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"title1\" "
      "value=\"%s\">\n",title1);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"TARGET\" "
      "value=\"%d\">\n",target);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"SIGNYN\" "
      "value=\"%d\">\n",signyn);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"SIGNFILE\" "
      "value=\"%d\">\n",sign);
	fprintf(cgiOut,"<input type=\"hidden\" name=\"board1\" "
      "value=\"%s\">\n",currboard);
    fprintf(cgiOut,"<input type=\"hidden\" name=\"comment1\" "
      "value=\"%s\">\n</form>", comment1);
     fprintf(cgiOut,"</body></html>\n");
      return 0;
    }

   strcpy(postfile.filename,filename2);
   strcpy(postfile.owner,name1);
   strcpy(postfile.title,title1);

   if (HAS_PERM(PERM_INTERNET)&&localsave) 
   	postfile.savemode='S'; //H
   else postfile.savemode='L'; //
   	//postfile.savemode=0x4d;
   	//postfile.savemode=0x4d;

   /*** gY ***/
   ltime=time(0);
   strftime(myfoo,20,"%m/%d/%Y",localtime(&ltime));
   myfoo[5]=0;
   if (myfoo[0]=='0') myfoo[0]=' ';
   strcpy(postfile.date,myfoo);
   if (target)
   {
     sprintf(filepath,BBSHOME "/home/%s/",receiver);
     sprintf(buf1,"%s.DIR",filepath);
   }
   else
   {
     sprintf(filepath,BBSHOME "/boards/%s/",currboard);
     sprintf(buf1,"%s.DIR",filepath);
   }

   if (!postmode)
     {
     if((fd = open(buf1,O_RDWR | O_CREAT | O_APPEND,0666)) == -1){
        cgiHeaderContentType("text/html");
        fprintf(cgiOut,"buf1=%sYɶ}ɥ<P> \n", buf1);
        return -1;
     }

     if( stat(buf1, &st ) >= 0 )
        numposts = st.st_size / (sizeof( struct fileheader ));
     else
        numposts = 0;
     if(lseek(fd,sizeof(postfile)*numposts,SEEK_SET) == -1){
        close(fd);
        cgiHeaderContentType("text/html");
        fprintf(cgiOut,"ɮ׳Bz2<P>\n");
        return -1;
     }
     write(fd, &postfile, sizeof(postfile));
     close(fd);
   
  }
  /*********  iK\ *****/
   if ((target==0)&&(postmode==0)) //`postQװ
   {
      /**** OwgŪLF **/
      brc_initial(currboard);
      brc_addlist(postfile.filename);   
      brc_update();
      cuser.numposts=cuser.numposts+1;
	oneline[0]=(char) sign;
	cuser.uflag = (cuser.uflag & ~SIG_FLAG) | (oneline[0] & SIG_FLAG);
      uid = searchuser(cuser.userid) ;
      if((substitute_record(fn_passwd, &cuser, sizeof(cuser), uid) == -1)||
        (uid==0))
      {
	    cgiHeaderContentType("text/html");
  	    fprintf(cgiOut," register numberpost  fail!!!\n");
      }
      setuserid(uid, cuser.userid);
      setbfile(location1,currboard,"wpostnum");
      logcnt(location1);
   }
   /**** Is **/
   if (where)
      sprintf(location1, "mlist.cgi");
   else
       sprintf(location1, "boards.cgi?%s", currboard);
   cgiHeaderLocation(location1);

   /** HXh **/
   if ((target==0)&&(HAS_PERM(PERM_INTERNET))&&localsave)
   {
     sprintf(buf1,"%s/innd/out.bntp",BBSHOME);
     if (fptr1 = fopen(buf1, "a")){
        fprintf(fptr1, "%s\t%s\t%s\t%s\t%s\n", currboard,
        filename2, name1,"FROM.FHLWBBS", title1);
        fclose(fptr1);
     }
   }
   return 0;
}
